@@ -19,6 +19,9 @@ with this program; if not, write to the Free Software Foundation, Inc.,
 
 #include "qlipperpreferences.h"
 
+const QString QlipperPreferences::DEFAULT_ICON_PATH = QStringLiteral(":/icons/qlipper.png");
+
+
 // allow to store ClipboardContent in the QSettings variant
 QDataStream &operator<<(QDataStream &out, const ClipboardContent &obj)
 {
@@ -164,6 +167,17 @@ void QlipperPreferences::saveDynamicItems(QList<QlipperItem> list)
     sync();
 }
 
+QString QlipperPreferences::getPathToIcon() const
+{
+    return value(QLatin1String("tray_icon_file"), DEFAULT_ICON_PATH).toString();
+}
+
+void QlipperPreferences::savePathToIcon(const QString &path)
+{
+    setValue(QLatin1String("tray_icon_file"), path);
+    sync();
+}
+
 bool QlipperPreferences::trim()
 {
     return value("trim", true).toBool();
@@ -189,9 +203,9 @@ bool QlipperPreferences::platformExtensions() const
     return value("platformExtensions", false).toBool();
 }
 
-bool QlipperPreferences::synchronizePSE() const
+QlipperPreferences::PSESynchronization QlipperPreferences::synchronizePSE() const
 {
-    return value("synchronizePSE", false).toBool();
+    return static_cast<PSESynchronization>(value("synchronizePSE", PSE_NO_SYNC).toInt());
 }
 
 bool QlipperPreferences::clearItemsOnExit() const
@@ -204,7 +218,6 @@ bool QlipperPreferences::synchronizeHistory() const
     return value("synchronizeHistory", true).toBool();
 }
 
-
 bool QlipperPreferences::networkSend() const
 {
     return value("networkSend", false).toBool();
@@ -222,5 +235,10 @@ int QlipperPreferences::networkPort() const
 
 bool QlipperPreferences::shouldSynchronizeClipboards() const
 {
-    return platformExtensions() && synchronizePSE();
+    return platformExtensions() && PSE_NO_SYNC != synchronizePSE();
+}
+
+bool QlipperPreferences::shouldSynchronizeClipboardsInstantly() const
+{
+    return platformExtensions() && PSE_SYNC_INSTANTLY == synchronizePSE();
 }
