@@ -21,12 +21,10 @@ with this program; if not, write to the Free Software Foundation, Inc.,
 #define QLIPPERSYSTRAY_H
 
 #include <QSystemTrayIcon>
-#include "config.h"
 
 
 class QlipperModel;
 class QMenuView;
-class QlipperMenuView;
 #ifndef NO_QXT
 class QxtGlobalShortcut;
 #endif
@@ -40,7 +38,7 @@ public:
 
 private:
     QlipperModel *m_model;
-    QlipperMenuView *m_contextMenu;
+    QMenu *m_contextMenu;
 #ifndef NO_QXT
     QMenuView *m_shortcutMenu;
     QxtGlobalShortcut *m_shortcut;
